changeset 14157:3c05b52ffad8 v8.1.0096

patch 8.1.0096: inconsistent use of the word autocommands commit https://github.com/vim/vim/commit/8c55533c6f109db2a0fff69651887f9474eb09c6 Author: Bram Moolenaar <Bram@vim.org> Date: Fri Jun 22 21:30:31 2018 +0200 patch 8.1.0096: inconsistent use of the word autocommands Problem: Inconsistent use of the word autocommands. Solution: Don't use auto-commands or "auto commands".
author Christian Brabandt <cb@256bit.org>
date Fri, 22 Jun 2018 21:45:05 +0200
parents 03824af50785
children 49172c13eab2
files src/fileio.c src/version.c
diffstat 2 files changed, 12 insertions(+), 10 deletions(-) [+]
line wrap: on
line diff
--- a/src/version.c
+++ b/src/version.c
@@ -762,6 +762,8 @@ static char *(features[]) =
 static int included_patches[] =
 {   /* Add new patch number below this line */
 /**/
+    96,
+/**/
     95,
 /**/
     94,
--- a/src/fileio.c
+++ b/src/fileio.c
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    will be automatically executed for <event>
  *				    when editing a file matching <pat>, in
  *				    the current group.
  * :autocmd <event> <pat>	    Show the auto-commands associated with
  *				    <event> and <pat>.
  * :autocmd <event>		    Show the auto-commands associated with
  *				    <event>.
  * :autocmd			    Show all auto-commands.
  * :autocmd! <event> <pat> <cmd>    Remove all auto-commands associated with
  *				    <event> and <pat>, and add the command
  *				    <cmd>, for the current group.
  * :autocmd! <event> <pat>	    Remove all auto-commands associated with
  *				    <event> and <pat> for the current group.
  * :autocmd! <event>		    Remove all auto-commands associated with
  *				    <event> for the current group.
  * :autocmd!			    Remove ALL auto-commands for the current
  *				    group.
  *
  *  Multiple events and patterns may be given separated by commas.  Here are
@@ -8534,7 +8534,7 @@ do_autocmd(char_u *arg_in, int forceit)
     if (!forceit && *cmd == NUL)
     {
 	/* Highlight title */
-	MSG_PUTS_TITLE(_("\n--- Auto-Commands ---"));
+	MSG_PUTS_TITLE(_("\n--- Autocommands ---"));
     }
 
     /*
@@ -9602,7 +9602,7 @@ apply_autocmds_group(
     autocmd_match = fname;
 
 
     /* Don't redraw while doing auto commands. */
     ++RedrawingDisabled;
     save_sourcing_name = sourcing_name;
     sourcing_name = NULL;	/* don't free this one */
@@ -9855,7 +9855,7 @@ auto_next_pat(
 		    : ap->buflocal_nr == apc->arg_bufnr)
 	    {
 		name = event_nr2name(apc->event);
-		s = _("%s Auto commands for \"%s\"");
+		s = _("%s Autocommands for \"%s\"");
 		sourcing_name = alloc((unsigned)(STRLEN(s)
 					    + STRLEN(name) + ap->patlen + 1));
 		if (sourcing_name != NULL)
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    when editing a file matching <pat>, in
  *				    the current group.
- * :autocmd <event> <pat>	    Show the auto-commands associated with
+ * :autocmd <event> <pat>	    Show the autocommands associated with
  *				    <event> and <pat>.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    <event> and <pat>.
- * :autocmd <event>		    Show the auto-commands associated with
+ * :autocmd <event>		    Show the autocommands associated with
  *				    <event>.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    <event>.
- * :autocmd			    Show all auto-commands.
- * :autocmd! <event> <pat> <cmd>    Remove all auto-commands associated with
+ * :autocmd			    Show all autocommands.
+ * :autocmd! <event> <pat> <cmd>    Remove all autocommands associated with
  *				    <event> and <pat>, and add the command
  *				    <cmd>, for the current group.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    <event> and <pat>, and add the command
  *				    <cmd>, for the current group.
- * :autocmd! <event> <pat>	    Remove all auto-commands associated with
+ * :autocmd! <event> <pat>	    Remove all autocommands associated with
  *				    <event> and <pat> for the current group.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    <event> and <pat> for the current group.
- * :autocmd! <event>		    Remove all auto-commands associated with
+ * :autocmd! <event>		    Remove all autocommands associated with
  *				    <event> for the current group.
@@ -8412,19 +8412,19 @@ au_event_restore(char_u *old_ei)
  *				    <event> for the current group.
- * :autocmd!			    Remove ALL auto-commands for the current
+ * :autocmd!			    Remove ALL autocommands for the current
  *				    group.
  *
@@ -9602,7 +9602,7 @@ apply_autocmds_group(
 
 
-    /* Don't redraw while doing auto commands. */
+    /* Don't redraw while doing autocommands. */
     ++RedrawingDisabled;
     save_sourcing_name = sourcing_name;